@@ -9,7 +9,8 @@ from pathlib import Path
 from time import perf_counter, sleep
 
 from .base import DrissionElement, BaseElement
-from .common import make_absolute_link, get_loc, get_ele_txt, format_html, is_js_func, _location_in_viewport
+from .common import make_absolute_link, get_loc, get_ele_txt, format_html, is_js_func, location_in_viewport, \
+    offset_scroll
 from .keys import _keys_to_typing, _keyDescriptionForString, _keyDefinitions
 from .session_element import make_session_ele
 
@@ -262,6 +263,14 @@ class ChromiumElement(DrissionElement):
         """
         return super().befores(filter_loc, timeout)
 
+    def afters(self, filter_loc='', timeout=None):
+        """返回当前元素后面符合条件的全部兄弟元素或节点组成的列表，可用查询语法筛选。查找范围不限兄弟元素，而是整个DOM文档        \n
+        :param filter_loc: 用于筛选元素的查询语法
+        :param timeout: 查找元素的超时时间
+        :return: 本元素前面的元素或节点组成的列表
+        """
+        return super().afters(filter_loc, timeout)
+
     def wait_ele(self, loc_or_ele, timeout=None):
         """返回用于等待子元素到达某个状态的等待器对象                    \n
         :param loc_or_ele: 可以是元素、查询字符串、loc元组
@@ -310,8 +319,8 @@ class ChromiumElement(DrissionElement):
     @property
     def is_in_viewport(self):
         """返回元素是否出现在视口中，以元素可以接受点击的点为判断"""
-        x, y = self.location
-        return _location_in_viewport(self.page, x, y) if x else False
+        x, y = self._click_point
+        return location_in_viewport(self.page, x, y) if x else False
 
     def attr(self, attr):
         """返回attribute属性值                           \n
@@ -640,7 +649,8 @@ class ChromiumElement(DrissionElement):
         :param button: 左键还是右键
         :return: None
         """
-        x, y = _offset_scroll(self, offset_x, offset_y)
+        self.page.scroll_to_see(self)
+        x, y = offset_scroll(self, offset_x, offset_y)
         self._click(x, y, button)
 
     def r_click(self):
@@ -649,12 +659,6 @@ class ChromiumElement(DrissionElement):
         x, y = self._client_click_point
         self._click(x, y, 'right')
 
-    def m_click(self):
-        """中键单击"""
-        self.page.scroll_to_see(self)
-        x, y = self._client_click_point
-        self._click(x, y, 'middle')
-
     def r_click_at(self, offset_x=None, offset_y=None):
         """带偏移量右键单击本元素，相对于左上角坐标。不传入x或y值时点击元素中点    \n
         :param offset_x: 相对元素左上角坐标的x轴偏移量
@@ -663,6 +667,12 @@ class ChromiumElement(DrissionElement):
         """
         self.click_at(offset_x, offset_y, 'right')
 
+    def m_click(self):
+        """中键单击"""
+        self.page.scroll_to_see(self)
+        x, y = self._client_click_point
+        self._click(x, y, 'middle')
+
     def _click(self, client_x, client_y, button='left'):
         """实施点击                        \n
         :param client_x: 视口中的x坐标
@@ -681,7 +691,8 @@ class ChromiumElement(DrissionElement):
         :param offset_y: 相对元素左上角坐标的y轴偏移量
         :return: None
         """
-        x, y = _offset_scroll(self, offset_x, offset_y)
+        self.page.scroll_to_see(self)
+        x, y = offset_scroll(self, offset_x, offset_y)
         self.page.driver.Input.dispatchMouseEvent(type='mouseMoved', x=x, y=y)
 
     def drag(self, offset_x=0, offset_y=0, speed=40, shake=True):
@@ -811,7 +822,7 @@ class ChromiumElement(DrissionElement):
         """
         try:
             return self.page.run_cdp('DOM.getBoxModel', nodeId=self.node_id, not_change=True)['model'][quad]
-        except:
+        except Exception:
             return None
 
     def _get_absolute_rect(self, x, y):
@@ -1289,6 +1300,7 @@ def run_js(page_or_ele, script, as_expr=False, timeout=None, args=None, not_chan
 
     exceptionDetails = res.get('exceptionDetails')
     if exceptionDetails:
+        print(script)
         raise RuntimeError(f'javascript错误: {exceptionDetails}')
 
     try:
@@ -1381,67 +1393,46 @@ def _send_key(ele, modifier, key):
         ele.page.driver.Input.dispatchKeyEvent(**data)
 
 
-def _offset_scroll(ele, offset_x, offset_y):
-    """接收元素及偏移坐标，滚动到偏移坐标，返回该点在视口中的坐标
-    :param ele: 元素对象
-    :param offset_x: 偏移量x
-    :param offset_y: 偏移量y
-    :return: 视口中的坐标
-    """
-    loc_x, loc_y = ele.location
-    cp_x, cp_y = ele._click_point
-    lx = loc_x + offset_x if offset_x else cp_x
-    ly = loc_y + offset_y if offset_y else cp_y
-
-    if not _location_in_viewport(ele.page, lx, ly):
-        ele.page.scroll.to_location(lx, ly)
-    cl_x, cl_y = ele.client_location
-    ccp_x, ccp_y = ele._client_click_point
-    cx = cl_x + offset_x if offset_x else ccp_x
-    cy = cl_y + offset_y if offset_y else ccp_y
-    return cx, cy
-
-
 class ChromiumScroll(object):
     """用于滚动的对象"""
 
     def __init__(self, page_or_ele):
         """
-        :param page_or_ele: ChromePage或ChromiumElement
+        :param page_or_ele: 页面对象、元素对象或frame对象
         """
-        self.page_or_ele = page_or_ele
+        self._driver = page_or_ele
         if isinstance(page_or_ele, ChromiumElement):
             self.t1 = self.t2 = 'this'
+        elif 'ChromiumFrame' in str(type(page_or_ele)):
+            self._driver = page_or_ele.doc_ele
+            self.t1 = self.t2 = 'this.documentElement'
         else:
             self.t1 = 'window'
             self.t2 = 'document.documentElement'
 
     def _run_js(self, js):
         js = js.format(self.t1, self.t2, self.t2)
-        if self.t1 == 'this':  # 在元素上滚动
-            self.page_or_ele.run_js(js)
-        else:
-            self.page_or_ele.run_js(js, as_expr=True)
+        self._driver.run_js(js)
 
     def to_top(self):
         """滚动到顶端，水平位置不变"""
-        self._run_js('{}.scrollTo({}.scrollLeft,0);')
+        self._run_js('{}.scrollTo({}.scrollLeft, 0);')
 
     def to_bottom(self):
         """滚动到底端，水平位置不变"""
-        self._run_js('{}.scrollTo({}.scrollLeft,{}.scrollHeight);')
+        self._run_js('{}.scrollTo({}.scrollLeft, {}.scrollHeight);')
 
     def to_half(self):
         """滚动到垂直中间位置，水平位置不变"""
-        self._run_js('{}.scrollTo({}.scrollLeft,{}.scrollHeight/2);')
+        self._run_js('{}.scrollTo({}.scrollLeft, {}.scrollHeight/2);')
 
     def to_rightmost(self):
         """滚动到最右边，垂直位置不变"""
-        self._run_js('{}.scrollTo({}.scrollWidth,{}.scrollTop);')
+        self._run_js('{}.scrollTo({}.scrollWidth, {}.scrollTop);')
 
     def to_leftmost(self):
         """滚动到最左边，垂直位置不变"""
-        self._run_js('{}.scrollTo(0,{}.scrollTop);')
+        self._run_js('{}.scrollTo(0, {}.scrollTop);')
 
     def to_location(self, x, y):
         """滚动到指定位置                 \n
@@ -1449,7 +1440,7 @@ class ChromiumScroll(object):
         :param y: 垂直距离
         :return: None
         """
-        self._run_js(f'{{}}.scrollTo({x},{y});')
+        self._run_js(f'{{}}.scrollTo({x}, {y});')
 
     def up(self, pixel=300):
         """向上滚动若干像素，水平位置不变    \n
@@ -1457,14 +1448,14 @@ class ChromiumScroll(object):
         :return: None
         """
         pixel = -pixel
-        self._run_js(f'{{}}.scrollBy(0,{pixel});')
+        self._run_js(f'{{}}.scrollBy(0, {pixel});')
 
     def down(self, pixel=300):
         """向下滚动若干像素，水平位置不变    \n
         :param pixel: 滚动的像素
         :return: None
         """
-        self._run_js(f'{{}}.scrollBy(0,{pixel});')
+        self._run_js(f'{{}}.scrollBy(0, {pixel});')
 
     def left(self, pixel=300):
         """向左滚动若干像素，垂直位置不变    \n
@@ -1472,14 +1463,14 @@ class ChromiumScroll(object):
         :return: None
         """
         pixel = -pixel
-        self._run_js(f'{{}}.scrollBy({pixel},0);')
+        self._run_js(f'{{}}.scrollBy({pixel}, 0);')
 
     def right(self, pixel=300):
         """向右滚动若干像素，垂直位置不变    \n
         :param pixel: 滚动的像素
         :return: None
         """
-        self._run_js(f'{{}}.scrollBy({pixel},0);')
+        self._run_js(f'{{}}.scrollBy({pixel}, 0);')
 
 
 class ChromiumSelect(object):
