@@ -133,7 +133,7 @@ class DriverElement(DrissionElement):
         """
         return make_session_ele(self, loc_or_str)
 
-    def s_eles(self, loc_or_str=None):
+    def s_eles(self, loc_or_str):
         """查找所有符合条件的元素以SessionElement列表形式返回                         \n
         :param loc_or_str: 定位符
         :return: SessionElement或属性、文本组成的列表
@@ -258,6 +258,7 @@ class DriverElement(DrissionElement):
         :param timeout: 查找元素的超时时间
         :return: 兄弟元素
         """
+        index, filter_loc = _exchange_arguments(index, filter_loc)
         return super().prev(index, filter_loc, timeout)
 
     def next(self, index=1, filter_loc='', timeout=0):
@@ -267,6 +268,7 @@ class DriverElement(DrissionElement):
         :param timeout: 查找元素的超时时间
         :return: 兄弟元素
         """
+        index, filter_loc = _exchange_arguments(index, filter_loc)
         return super().next(index, filter_loc, timeout)
 
     def before(self, index=1, filter_loc='', timeout=None):
@@ -276,6 +278,7 @@ class DriverElement(DrissionElement):
         :param timeout: 查找元素的超时时间
         :return: 本元素前面的某个元素或节点
         """
+        index, filter_loc = _exchange_arguments(index, filter_loc)
         return super().before(index, filter_loc, timeout)
 
     def after(self, index=1, filter_loc='', timeout=None):
@@ -285,6 +288,7 @@ class DriverElement(DrissionElement):
         :param timeout: 查找元素的超时时间
         :return: 本元素后面的某个元素或节点
         """
+        index, filter_loc = _exchange_arguments(index, filter_loc)
         return super().after(index, filter_loc, timeout)
 
     def prevs(self, filter_loc='', timeout=0):
@@ -1136,7 +1140,7 @@ class ElementWaiter(object):
         return self._wait_ele('hidden')
 
     def _wait_ele(self, mode):
-        """执行等待
+        """执行等待              \n
         :param mode: 等待模式
         :return: 是否等待成功
         """
@@ -1245,3 +1249,14 @@ class Scroll(object):
         :return: None
         """
         self.driver.run_script(f'{self.t1}.scrollBy({pixel},0);')
+
+
+def _exchange_arguments(index, filter_loc):
+    # 此方法用于兼容MixPage参数顺序相反的情况
+    if isinstance(index, str) and isinstance(filter_loc, int):
+        index, filter_loc = filter_loc, index
+    elif isinstance(index, int) and filter_loc == 1:
+        filter_loc = ''
+    elif isinstance(filter_loc, str) and index == '':
+        index = 1
+    return index, filter_loc
